@@ -1,6 +1,10 @@
 
+#ifndef __glade_marshal_MARSHAL_H__
+#define __glade_marshal_MARSHAL_H__
+
 #include	<glib-object.h>
 
+G_BEGIN_DECLS
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -48,6 +52,12 @@
 
 
 /* VOID:POINTER,POINTER (./glade-marshallers.list:1) */
+extern void glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
 void
 glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                      GValue       *return_value,
@@ -85,6 +95,12 @@ glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
 }
 
 /* VOID:STRING,ULONG,UINT,STRING (./glade-marshallers.list:2) */
+extern void glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
+                                                          GValue       *return_value,
+                                                          guint         n_param_values,
+                                                          const GValue *param_values,
+                                                          gpointer      invocation_hint,
+                                                          gpointer      marshal_data);
 void
 glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
                                               GValue       *return_value,
@@ -126,8 +142,15 @@ glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
 }
 
 /* VOID:OBJECT (./glade-marshallers.list:3) */
+#define glade_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
 /* VOID:OBJECT,BOOLEAN (./glade-marshallers.list:4) */
+extern void glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
 void
 glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                     GValue       *return_value,
@@ -165,6 +188,12 @@ glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
 }
 
 /* VOID:STRING,STRING,STRING (./glade-marshallers.list:5) */
+extern void glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
+                                                      GValue       *return_value,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint,
+                                                      gpointer      marshal_data);
 void
 glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                           GValue       *return_value,
@@ -204,6 +233,12 @@ glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
 }
 
 /* OBJECT:POINTER (./glade-marshallers.list:6) */
+extern void glade_marshal_OBJECT__POINTER (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
 void
 glade_marshal_OBJECT__POINTER (GClosure     *closure,
                                GValue       *return_value,
@@ -243,6 +278,12 @@ glade_marshal_OBJECT__POINTER (GClosure     *closure,
 }
 
 /* OBJECT:OBJECT,UINT (./glade-marshallers.list:7) */
+extern void glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
 void
 glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
                                    GValue       *return_value,
@@ -284,6 +325,12 @@ glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
 }
 
 /* BOOLEAN:STRING (./glade-marshallers.list:8) */
+extern void glade_marshal_BOOLEAN__STRING (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__STRING (GClosure     *closure,
                                GValue       *return_value,
@@ -323,6 +370,12 @@ glade_marshal_BOOLEAN__STRING (GClosure     *closure,
 }
 
 /* BOOLEAN:BOXED (./glade-marshallers.list:9) */
+extern void glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
                               GValue       *return_value,
@@ -362,6 +415,12 @@ glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT (./glade-marshallers.list:10) */
+extern void glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                GValue       *return_value,
@@ -401,6 +460,12 @@ glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT,BOXED (./glade-marshallers.list:11) */
+extern void glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                      GValue       *return_value,
@@ -442,6 +507,12 @@ glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:12) */
+extern void glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
+                                                   GValue       *return_value,
+                                                   guint         n_param_values,
+                                                   const GValue *param_values,
+                                                   gpointer      invocation_hint,
+                                                   gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                        GValue       *return_value,
@@ -483,6 +554,12 @@ glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:13) */
+extern void glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
+                                                   GValue       *return_value,
+                                                   guint         n_param_values,
+                                                   const GValue *param_values,
+                                                   gpointer      invocation_hint,
+                                                   gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
@@ -524,6 +601,12 @@ glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:14) */
+extern void glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
                                     GValue       *return_value,
@@ -565,6 +648,12 @@ glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:15) */
+extern void glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
+                                                  GValue       *return_value,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint,
+                                                  gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                       GValue       *return_value,
@@ -606,6 +695,12 @@ glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT,STRING (./glade-marshallers.list:16) */
+extern void glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
+                                                  GValue       *return_value,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint,
+                                                  gpointer      marshal_data);
 void
 glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                       GValue       *return_value,
@@ -647,6 +742,12 @@ glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
 }
 
 /* STRING:OBJECT (./glade-marshallers.list:17) */
+extern void glade_marshal_STRING__OBJECT (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
 void
 glade_marshal_STRING__OBJECT (GClosure     *closure,
                               GValue       *return_value,
@@ -685,3 +786,7 @@ glade_marshal_STRING__OBJECT (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
+G_END_DECLS
+
+#endif /* __glade_marshal_MARSHAL_H__ */
+
